[Compare the full difference.](https://github.com/callowayproject/bump-my-version/compare/1.2.1...1.2.2)

### Fixes

- Fixed code style, ensure encoding consistency, and update dependencies in pre-commit configuration. [91d5eff](https://github.com/callowayproject/bump-my-version/commit/91d5eff6387185e48396ab1d285139aff8ad4407)
    
### Other

- Bump the github-actions group across 1 directory with 3 updates. [b8e2f1c](https://github.com/callowayproject/bump-my-version/commit/b8e2f1c397a937b0496c0120878807f1973c6c57)
    
  Bumps the github-actions group with 3 updates in the / directory: [actions/checkout](https://github.com/actions/checkout), [actions/setup-python](https://github.com/actions/setup-python) and [actions/download-artifact](https://github.com/actions/download-artifact).


  Updates `actions/checkout` from 4 to 5
  - [Release notes](https://github.com/actions/checkout/releases)
  - [Changelog](https://github.com/actions/checkout/blob/main/CHANGELOG.md)
  - [Commits](https://github.com/actions/checkout/compare/v4...v5)

  Updates `actions/setup-python` from 5 to 6
  - [Release notes](https://github.com/actions/setup-python/releases)
  - [Commits](https://github.com/actions/setup-python/compare/v5...v6)

  Updates `actions/download-artifact` from 4 to 5
  - [Release notes](https://github.com/actions/download-artifact/releases)
  - [Commits](https://github.com/actions/download-artifact/compare/v4...v5)

  ---
  **updated-dependencies:** - dependency-name: actions/checkout
dependency-version: '5'
dependency-type: direct:production
update-type: version-update:semver-major
dependency-group: github-actions

  **signed-off-by:** dependabot[bot] <support@github.com>

- [pre-commit.ci] pre-commit autoupdate. [846fedd](https://github.com/callowayproject/bump-my-version/commit/846fedd4b166f3f83ae04b72d9c6635d59f0cae2)
    
  **updates:** - [github.com/astral-sh/ruff-pre-commit: v0.12.3 → v0.12.12](https://github.com/astral-sh/ruff-pre-commit/compare/v0.12.3...v0.12.12)

### Updates

- Update dependency versions and Python compatibility markers in uv.lock. [f8f33d0](https://github.com/callowayproject/bump-my-version/commit/f8f33d0bf5c3610d265f7437734e8604fdfbf269)
    
